import Vue from 'vue'
import Vuex from 'vuex'
import { getUser, logout, getPermissions, getAllProjects, getQuestionCategory } from '@/api/base'

Vue.use(Vuex)

const store = new Vuex.Store({
  state: {
    user: {}, // 用户信息
    organization: {}, // 机构信息
    roles: [], // 角色列表
    permissions: [], // 权限列表
    projects: [], // 项目列表
    activeProject: {}, // 当前激活的项目
    questionCategory: [] // 试题分类
  },
  mutations: {
    setUser(state, user) {
      state.user = user
    },
    setPermissions(state, data = {}) {
      state.permissions = data.permissions || []
      state.roles = data.roles || []
      state.organization = data.organization || {}
      // 当前激活的项目
      const localProjectTag = localStorage.getItem('project_tag')
      state.activeProject = localProjectTag ? { tag: localProjectTag } : data.project || {}
    },
    setProjects(state, projects) {
      state.projects = projects
    },
    setActiveProject(state, project = {}) {
      state.activeProject = project
      localStorage.setItem('project_tag', project.tag || '')
    },
    setQuestionCategory(state, questionCategory) {
      state.questionCategory = questionCategory
    }
  },
  actions: {
    // 获取所有项目列表
    getAllProjects({ commit }) {
      getAllProjects().then(res => {
        const projects = res.data || []
        // 所有项目列表
        commit('setProjects', projects)
      })
    },
    // 获取用户信息
    getUser({ commit }) {
      getUser().then(response => {
        commit('setUser', response)
      })
    },
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        return response
      })
    },
    async checkLogin({ commit, dispatch }) {
      const isLogin = await getUser()
        .then(response => {
          if (response.code === 0) {
            commit('setUser', response.data)
            return true
          } else {
            commit('setUser', {})
            return false
          }
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      await dispatch('getPermissions')
      return isLogin
    },
    // 获取所有权限列表
    async getPermissions({ commit, state }) {
      await getPermissions({ id: state.user.id }).then(res => {
        res.data && commit('setPermissions', res.data)
      })
    },
    getQuestionCategory({ commit }, params) {
      return getQuestionCategory(params).then(res => {
        commit('setQuestionCategory', res.data)
        return res.data
      })
    }
  }
})

export default store
